import { HttpRequest } from "./httprequest";
import { HttpResponse } from "./httpresponse";
import { IFilter } from "../tools/types";
/**
 * 过滤器工厂类
 * 如果处理方法返回false，表示后续过滤器方法不再执行
 */
export declare class FilterFactory {
    /**
     * 过滤器实例数组
     */
    private static filters;
    /**
     * 处理实例过滤器
     * @param instanceName  实例名
     * @param className     类名
     * @since 1.0.0
     */
    static addFilter(cfg: IFilter): void;
    /**
     * @exclude
     * 文件解析
     * @param path      filter的json文件
     */
    /**
     * 初始化
     * @param config {filters:[{IFilterCfg1},...]}
     */
    /**
     * 获取过滤器链
     * @param url   资源url
     * @returns     filter数组
     */
    static getFilterChain(url: string): Array<IFilter>;
    /**
     * 执行过滤器链
     * @param url       url路径
     * @param request   request 对象
     * @param response  response 对象
     * @returns         全部执行完为true，否则为false
     */
    static doChain(url: string, request: HttpRequest, response: HttpResponse): Promise<boolean>;
}
